SuperfluPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- SuperfluPlatform
- Implementers
Constructors
- SuperfluPlatform()
- Constructs a SuperfluPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getInstall(
) → Future< Map< String, dynamic> ?> -
getPlatformVersion(
) → Future< String?> -
init(
String app_key, String secret) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
point(
String pointId, int value) → void -
register(
String id) → void -
setChannel(
String channel) → void -
setDebug(
bool isDebug) → void -
setHost(
String hosts) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ SuperfluPlatform
-
The default instance of SuperfluPlatform to use.
getter/setter pair