MethodChannelSuperflu class
An implementation of SuperfluPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- SuperfluPlatform
- MethodChannelSuperflu
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getInstall(
) → Future< Map< String, dynamic> ?> -
override
-
getPlatformVersion(
) → Future< String?> -
override
-
init(
String app_key, String secret) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
point(
String pointId, int value) → void -
override
-
register(
String id) → void -
override
-
setChannel(
String channel) → void -
override
-
setDebug(
bool isDebug) → void -
override
-
setHost(
String hosts) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited