SuperfluWeb class
A web implementation of the SuperfluPlatform of the Superflu plugin.
- Inheritance
-
- Object
- PlatformInterface
- SuperfluPlatform
- SuperfluWeb
Constructors
- SuperfluWeb()
- Constructs a SuperfluWeb
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getInstall(
) → Future< Map< String, dynamic> ?> -
override
-
getPlatformVersion(
) → Future< String?> -
Returns a String containing the version of the platform.
override
-
init(
String app_key, String secret) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
point(
String pointId, int value) → void -
override
-
register(
String ids) → void -
override
-
setChannel(
String channel) → void -
override
-
setDebug(
bool isDebug) → void -
override
-
setHost(
String hosts) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
Registrar registrar) → void